@@ -21,10 +21,11 @@
 Glance API Server
 """
 
-import eventlet
 import os
 import sys
 
+import eventlet
+
 from glance.common import utils
 
 # Monkey patch socket, time, select, threads
@@ -40,7 +41,8 @@ if os.path.exists(os.path.join(possible_topdir, 'glance', '__init__.py')):
     sys.path.insert(0, possible_topdir)
 
 import glance_store
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_log import log as logging
 import osprofiler.notifier
 import osprofiler.web
 
@@ -48,26 +50,28 @@ from glance.common import config
 from glance.common import exception
 from glance.common import wsgi
 from glance import notifier
-from glance.openstack.common import log
 
 CONF = cfg.CONF
 CONF.import_group("profiler", "glance.common.wsgi")
+logging.register_options(CONF)
+
+KNOWN_EXCEPTIONS = (RuntimeError,
+                    exception.WorkerCreationFailure,
+                    glance_store.exceptions.BadStoreConfiguration)
 
 
-def fail(returncode, e):
+def fail(e):
+    global KNOWN_EXCEPTIONS
+    return_code = KNOWN_EXCEPTIONS.index(type(e)) + 1
     sys.stderr.write("ERROR: %s\n" % utils.exception_to_str(e))
-    sys.exit(returncode)
+    sys.exit(return_code)
 
 
 def main():
     try:
         config.parse_args()
         wsgi.set_eventlet_hub()
-        log.setup('glance')
-
-        glance_store.register_opts(config.CONF)
-        glance_store.create_stores(config.CONF)
-        glance_store.verify_default_store()
+        logging.setup(CONF, 'glance')
 
         if cfg.CONF.profiler.enabled:
             _notifier = osprofiler.notifier.create("Messaging",
@@ -79,13 +83,11 @@ def main():
         else:
             osprofiler.web.disable()
 
-        server = wsgi.Server()
+        server = wsgi.Server(initialize_glance_store=True)
         server.start(config.load_paste_app('glance-api'), default_port=9292)
         server.wait()
-    except exception.WorkerCreationFailure as e:
-        fail(2, e)
-    except RuntimeError as e:
-        fail(1, e)
+    except KNOWN_EXCEPTIONS as e:
+        fail(e)
 
 
 if __name__ == '__main__':
